pub struct MetaFlag(/* private fields */);Expand description
Represents metadata flags for a configuration entity.
These flags provide hints and directives to the config system (config-it)
about how to treat and interact with the associated configuration variable.
Implementations
Sourceimpl MetaFlag
impl MetaFlag
Sourcepub const HIDDEN_NON_ADMIN: Self
pub const HIDDEN_NON_ADMIN: Self
Advises the monitor to hide this variable from non-admin users.
Sourcepub const HIDDEN: Self
pub const HIDDEN: Self
Advises the monitor to hide this variable from all users, regardless of role.
Sourcepub const ADMIN_READ: Self
pub const ADMIN_READ: Self
Indicates that only admin users should be allowed to read this variable.
Sourcepub const ADMIN_WRITE: Self
pub const ADMIN_WRITE: Self
Indicates that only admin users should be allowed to write to this variable. Implicitly
includes the ADMIN_READ permission.
Sourcepub const READONLY: Self
pub const READONLY: Self
Designates the variable as read-only, ensuring that no user, even admins, can modify its value.
Sourcepub const WRITEONLY: Self
pub const WRITEONLY: Self
Marks the variable as write-only. This means its value cannot be read or accessed (useful for secrets, where the value might be set but not retrieved).
Sourcepub const SECRET: Self
pub const SECRET: Self
Ensures that the variable’s value is encrypted when stored. Implicitly includes the
WRITEONLY property, reflecting the sensitive nature of the data.
Sourceimpl MetaFlag
impl MetaFlag
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl MetaFlag
impl MetaFlag
Sourcepub const fn iter(&self) -> Iter<MetaFlag>
pub const fn iter(&self) -> Iter<MetaFlag>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<MetaFlag>
pub const fn iter_names(&self) -> IterNames<MetaFlag>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.