Metadata

Struct Metadata 

#[non_exhaustive]
pub struct Metadata { pub name: &'static str, pub varname: &'static str, pub type_name: &'static str, pub flags: MetaFlag, pub editor_hint: Option<MetadataEditorHint>, pub description: &'static str, pub env: Option<&'static str>, }
Describes metadata for a configuration entity, intended for utilization by external tools.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: &'static str

Unique identifier for this configuration entity.

varname: &'static str

Source variable name from the configuration definition. It’s typically identical to ‘name’ unless an alternative name is explicitly set.

type_name: &'static str

String representation of the type for this configuration entity.

flags: MetaFlag

Flags that denote various behaviors and hints associated with the configuration entity.

editor_hint: Option<MetadataEditorHint>

Provides guidance for a monitoring editor on how to interact with this variable. While this crate doesn’t use this hint directly, it helps external monitors understand the preferred method to edit the variable.

description: &'static str

A brief description that elaborates on the purpose or role of the configuration entity.

env: Option<&'static str>

Corresponding environment variable name, if any, that maps to this configuration entity.