pub struct ItemID(pub u64);Expand description
Represents a unique identifier for an individual item or element.
ItemID allows for the differentiation and management of individual configuration items
within the storage or a group. Each item, whether it’s a variable, property, or another
entity, is assigned a unique ID for precise operations and management.
The From trait support ensures that ItemID can be easily constructed from other relevant
types.
Tuple Fields
0: u64Trait Implementations
Sourceimpl<'de> Deserialize<'de> for ItemID
impl<'de> Deserialize<'de> for ItemID
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Ord for ItemID
impl Ord for ItemID
Sourceimpl PartialOrd for ItemID
impl PartialOrd for ItemID
impl Copy for ItemID
impl Eq for ItemID
impl StructuralPartialEq for ItemID